from setuptools import setup

setup(name='distributions_esra',
      version='2.5',
      description='Gaussian distributions',
      packages=['distributions_esra'],
      author = "esra ai",
      author_email = "esra.al@gmail.com",
      zip_safe=False)
